# -*- coding: utf-8 -*-
# Generated by Django 1.11.1 on 2019-11-22 05:40
from __future__ import unicode_literals

import bee_django_richtext.custom_fields
from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('bee_django_wiki', '0007_auto_20190903_1846'),
    ]

    operations = [
        migrations.AlterField(
            model_name='topic',
            name='detail',
            field=bee_django_richtext.custom_fields.RichTextField(app_name='bee_django_wiki', emotion=False, image_max_size=2, img=False, model_name='Topic', text_min_length=5, undo_redo=False, verbose_name='\u8be6\u60c5'),
        ),
    ]
