# -*- coding: utf-8 -*-
# Generated by Django 1.11.1 on 2019-09-03 08:45
from __future__ import unicode_literals

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('bee_django_wiki', '0001_initial'),
    ]

    operations = [
        migrations.RenameField(
            model_name='topic',
            old_name='classfify',
            new_name='classify',
        ),
    ]
