# -*- coding: utf-8 -*-
# Generated by Django 1.11.1 on 2019-09-03 10:22
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('bee_django_wiki', '0005_auto_20190903_1714'),
    ]

    operations = [
        migrations.CreateModel(
            name='TopicImage',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('image', models.ImageField(upload_to='wiki/%Y/%m/%d', verbose_name='\u56fe\u7247')),
            ],
            options={
                'db_table': 'bee_django_wiki_toipc_image',
            },
        ),
    ]
