# -*- coding: utf-8 -*-
# Generated by Django 1.11.1 on 2019-08-30 08:44
from __future__ import unicode_literals

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    initial = True

    dependencies = [
    ]

    operations = [
        migrations.CreateModel(
            name='Classify',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(max_length=180, verbose_name='\u5206\u7c7b')),
            ],
            options={
                'db_table': 'bee_django_wiki_classify',
                'permissions': (('view_all_classify', '\u53ef\u4ee5\u67e5\u770b\u5206\u7c7b'),),
            },
        ),
        migrations.CreateModel(
            name='Topic',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('title', models.CharField(max_length=180, verbose_name='\u6807\u9898')),
                ('detail', models.TextField(verbose_name='\u8be6\u60c5')),
                ('tag', models.CharField(max_length=180, null=True, verbose_name='\u6807\u7b7e')),
                ('created_at', models.DateTimeField(auto_now_add=True)),
                ('updated_at', models.DateTimeField(auto_now=True)),
                ('order_by', models.IntegerField(default=0, null=True, verbose_name='\u6392\u5e8f')),
                ('view_group', models.TextField(null=True, verbose_name='\u53ef\u89c2\u770b\u7684\u7528\u6237\u7ec4')),
                ('classfify', models.ForeignKey(null=True, on_delete=django.db.models.deletion.SET_NULL, to='bee_django_wiki.Classify', verbose_name='\u5206\u7c7b')),
            ],
            options={
                'ordering': ['-updated_at'],
                'db_table': 'bee_django_wiki_topic',
                'permissions': (('view_all_topic', '\u67e5\u770b\u6240\u6709\u4e3b\u9898'),),
            },
        ),
    ]
