# -*- coding: utf-8 -*-
# Generated by Django 1.11.1 on 2019-09-03 10:46
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('bee_django_wiki', '0006_topicimage'),
    ]

    operations = [
        migrations.AlterField(
            model_name='topic',
            name='view_group',
            field=models.ManyToManyField(to='auth.Group', verbose_name='\u53ef\u89c2\u770b\u7684\u7528\u6237\u7ec4\uff08\u53ef\u591a\u9009\uff09'),
        ),
    ]
