# -*- coding: utf-8 -*-
# Generated by Django 1.11.1 on 2019-09-03 09:14
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('auth', '0008_alter_user_username_max_length'),
        ('bee_django_wiki', '0003_auto_20190903_1650'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='topic',
            name='view_group',
        ),
        migrations.AddField(
            model_name='topic',
            name='view_group',
            field=models.ManyToManyField(to='auth.Group'),
        ),
    ]
