# -*- coding: utf-8 -*-
# Generated by Django 1.11.1 on 2019-09-03 08:50
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('bee_django_wiki', '0002_auto_20190903_1645'),
    ]

    operations = [
        migrations.AlterField(
            model_name='topic',
            name='tag',
            field=models.CharField(blank=True, max_length=180, null=True, verbose_name='\u6807\u7b7e'),
        ),
    ]
